### TODO

- data structure visualization, maybe (vis data) dispatched on type?
- persistent state (repl image) - criu?
- code suggestion? (not sure I want this) - jedhy
- auto indent in repl
- parinfer in repl
- nrepl by default / enable within repl
- multiple nrepl clients to the same server instance
